#!/usr/bin/env python3

import usb.core
import usb.util
import time
import os

LANG_EN = 0x0409

VENDOR_ID = 0x4242
PRODUCT_ID = 0xe131

MANUFACTURER_INDEX = 1
PRODUCT_INDEX = 2

MANUFACTURER_NAME = 'upb.ro'
PRODUCT_NAME = 'PM Keypad'

# USB_OUT = host to device && Vendor && Device
# USB_IN  = device to host && Vendor && Device
# according to https://www.beyondlogic.org/usbnutshell/usb6.shtml
USB_OUT = 0x40
USB_IN  = 0xC0

VREQ_STATUS            = 0x00
VREQ_GET_BUTTONS       = 0x01
VREQ_SET_STATUS_HID    = 0x02
VREQ_SET_STATUS_VENDOR = 0x03
VREQ_TOGGLE_STATUS     = 0x04

STATUS_HID    = 0x00
STATUS_VENDOR = 0x01

NUM_BUTTONS = 36

def get_device():
    """
    Returns the device we're looking for (the one
    with our VID/PID and our manufacturer and product
    strings). If it's not found, it returns None
    """
    dev = None

    try:
        dev = usb.core.find(idVendor=VENDOR_ID, idProduct=PRODUCT_ID);
        if dev is None:
            return None

        manufacturer = usb.util.get_string(dev, MANUFACTURER_INDEX, LANG_EN)
        product = usb.util.get_string(dev, PRODUCT_INDEX, LANG_EN)

        if manufacturer != MANUFACTURER_NAME:
            return None

        if product != PRODUCT_NAME:
            return None
    except:
        return None

    return dev


def wait_for_device():
    """
    Tries to get the device every second. It returns
    the device once it finds it.
    """
    dev = None

    # wait until the device connects
    while True:
        try:
            print('waiting for the device to connect')
            dev = get_device()
            if dev is not None:
                break
            time.sleep(1)
        except:
            pass

    print('device connected')
    return dev


def main():
    dev = get_device()
    if dev is None:
        return

    dev.ctrl_transfer(USB_OUT, VREQ_TOGGLE_STATUS, 0, 0)

if __name__ == '__main__':
    main()
